==> haskell-bifunctors-5.6.2-57.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bifunctors
version:              5.6.2
visibility:           public
id:                   bifunctors-5.6.2-46LlpbtsnGiKfj3D3n0SSf
key:                  bifunctors-5.6.2-46LlpbtsnGiKfj3D3n0SSf
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/bifunctors/
synopsis:             Bifunctors
description:          Bifunctors.
category:             Data, Functors
abi:                  73a061b8f55c69958b06689373a00497
exposed:              True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biap Data.Bifunctor.Biff
    Data.Bifunctor.Clown Data.Bifunctor.Fix Data.Bifunctor.Flip
    Data.Bifunctor.Functor Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Sum Data.Bifunctor.TH
    Data.Bifunctor.Tannen Data.Bifunctor.Wrapped

hidden-modules:       Data.Bifunctor.TH.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bifunctors-5.6.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bifunctors-5.6.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bifunctors-5.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bifunctors
hs-libraries:         HSbifunctors-5.6.2-46LlpbtsnGiKfj3D3n0SSf
depends:
    assoc-1.1.1-CXSd7PfWtZ44ssseqrHtHW base-4.18.2.1
    comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot containers-0.6.7
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html:         /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bifunctors-5.6.2-58-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bifunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bifunctors
version:              5.6.2
visibility:           public
id:                   bifunctors-5.6.2-A3wf66Vnx89CEVmymYgSB
key:                  bifunctors-5.6.2-A3wf66Vnx89CEVmymYgSB
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/bifunctors/
synopsis:             Bifunctors
description:          Bifunctors.
category:             Data, Functors
abi:                  91d2540b73af8003a12d696dc97f43af
exposed:              True
exposed-modules:
    Data.Biapplicative Data.Bifunctor.Biap Data.Bifunctor.Biff
    Data.Bifunctor.Clown Data.Bifunctor.Fix Data.Bifunctor.Flip
    Data.Bifunctor.Functor Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Sum Data.Bifunctor.TH
    Data.Bifunctor.Tannen Data.Bifunctor.Wrapped

hidden-modules:       Data.Bifunctor.TH.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bifunctors-5.6.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bifunctors-5.6.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bifunctors-5.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bifunctors
hs-libraries:         HSbifunctors-5.6.2-A3wf66Vnx89CEVmymYgSB
depends:
    assoc-1.1.1-CXSd7PfWtZ44ssseqrHtHW base-4.18.2.1
    comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL containers-0.6.7
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig template-haskell-2.20.0.0
    th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-bifunctors/html/bifunctors.haddock
haddock-html:         /usr/share/doc/haskell-bifunctors/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
